import Vue from 'vue'
import Vuex from 'vuex'
import {Aid} from "@/model/Aid";
import {Quarter} from "@/model/Quarter";
import {Month} from "@/model/Month";
import argumentStore from "@/store/ArgumentStore"
import trainingPlanStore from "@/store/TrainingPlanStore"
import aidStore from "@/store/AidStore"
import {Probability} from "@/model/Probability";
import registeredFallStore from "@/store/RegisteredFallStore";

Vue.use(Vuex)

export default new Vuex.Store({
    state: {
        authenticated: true,
        probability_complete: new Probability(0),
        probability_fall: new Probability(0),
        quarters: [
            new Quarter(2018, 1,
                new Month(0, 5, new Date(2018, 0)),
                new Month(0, 5, new Date(2018, 1)),
                new Month(0, 5, new Date(2018, 2))
            ),
            new Quarter(2018, 2,
                new Month(0, 8, new Date(2018, 3)),
                new Month(0, 8, new Date(2018, 4)),
                new Month(0, 8, new Date(2018, 5))
            ),
            new Quarter(2018, 3,
                new Month(0, 8, new Date(2018, 6)),
                new Month(0, 10, new Date(2018, 7)),
                new Month(0, 10, new Date(2018, 8))
            ),
            new Quarter(2018, 4,
                new Month(0, 10, new Date(2018, 9)),
                new Month(0, 10, new Date(2018, 10)),
                new Month(0, 10, new Date(2018, 11))
            ),
            new Quarter(2019, 1,
                new Month(0, 10, new Date(2019, 0)),
                new Month(0, 10, new Date(2019, 1)),
                new Month(0, 15, new Date(2019, 2))
            ),
            new Quarter(2019, 2,
                new Month(0, 15, new Date(2019, 3)),
                new Month(0, 15, new Date(2019, 4)),
                new Month(0, 15, new Date(2019, 5))
            ),
            new Quarter(2019, 3,
                new Month(0, 10, new Date(2019, 6)),
                new Month(0, 10, new Date(2019, 7)),
                new Month(0, 10, new Date(2019, 8))
            ),
            new Quarter(2019, 4,
                new Month(0, 10, new Date(2019, 9)),
                new Month(0, 20, new Date(2019, 10)),
                new Month(0, 20, new Date(2019, 11))
            ),
            new Quarter(2020, 1,
                new Month(0, 20, new Date(2020, 0)),
                new Month(0, 20, new Date(2020, 1)),
                new Month(0, 20, new Date(2020, 2))
            ),
            new Quarter(2020, 2,
                new Month(0, 20, new Date(2020, 3)),
                new Month(0, 20, new Date(2020, 4)),
                new Month(0, 20, new Date(2020, 5))
            ),
            new Quarter(2020, 3,
                new Month(0, 20, new Date(2020, 6)),
                new Month(0, 20, new Date(2020, 7)),
                new Month(0, 20, new Date(2020, 8))
            ),
            new Quarter(2020, 4,
                new Month(0, 20, new Date(2020, 9)),
                new Month(0, 20, new Date(2020, 10)),
                new Month(0, 20, new Date(2020, 11))
            ),

        ]
    },
    mutations: {
        SET_AUTHENTICATED(state) {
            state.authenticated = true
        },
        SET_PROBABILITY_COMPLETE(state, value) {
            state.probability_complete = new Probability(value)
        },
        SET_PROBABILITY_FALL(state, value) {
            state.probability_fall = new Probability(value)
        },
    },
    actions: {
        authenticateUser({commit}) {
            commit('SET_AUTHENTICATED')
        },
        addProbabilityComplete({commit}, value) {
            commit('SET_PROBABILITY_COMPLETE', value)
        },
        addProbabilityFall({commit}, value) {
            commit('SET_PROBABILITY_FALL', value)
        },
    },
    getters: {
        quarters: (state, rootGetters) => {
            let quarters = state.quarters
            let aids: Aid[] = rootGetters.activeAids

            quarters.forEach(value => {
                value.month1.aids = aids.filter((x: Aid) => x.dateReceived < new Date(value.year, value.month1.date.getMonth())).length
                value.month2.aids = aids.filter((x: Aid) => x.dateReceived < new Date(value.year, value.month2.date.getMonth())).length
                value.month3.aids = aids.filter((x: Aid) => x.dateReceived < new Date(value.year, value.month3.date.getMonth())).length
            })

            return quarters
        },
        probability_complete: state => state.probability_complete,
        probability_fall: state => state.probability_fall,
        authenticated: state => state.authenticated,
    },
    modules: {
        argumentStore,
        trainingPlanStore,
        aidStore,
        registeredFallStore
    }
})
